==> python-pmw_0.8.1.orig.tar.gz: Pmw/Pmw_0_8_1/demos/LogicalFont.py <==
""" Demonstration of the Pmw LogicalFont functions.
"""

# Import Pmw from the sibling directory.
import sys
sys.path[:0] = ['../../..']

import string
import Tkinter
import Pmw

class Demo:

    # The fonts to demonstrate.
    fontList = (
      (('Times', 0), {}),
      (('Helvetica', 0), {}),
      (('Typewriter', 0), {}),
      (('Fixed', 0), {}),
      (('Helvetica', 2), {'slant' : 'italic'}),
      (('Helvetica', 0), {'size' : 18}),
      (('Helvetica', 0), {'weight' : 'bold'}),
      (('Helvetica', 12), {'weight' : 'bold', 'slant' : 'italic'}),
      (('Typewriter', 0), {'size' : 8, 'weight' : 'bold'}),
      (('Fixed', 0), {'size' : 8, 'weight' : 'bold'}),
      (('Times', 0), {'size' : 24, 'weight' : 'bold', 'slant' : 'italic'}),
      (('Typewriter', 0), {'width' : 'condensed'}),
      (('Typewriter', -1), {'width' : 'condensed'}),
      (('Fixed', 0), {'width' : 'condensed'}),
      (('Fixed', -1), {'width' : 'condensed'}),
      (('Helvetica', 0), {'weight' : 'bogus'}),
    )

    fontText = []

    def __init__(self, parent):

	self.parent = parent

	# Create a label to display the selected font.
	self.target = Tkinter.Label(parent,
	        text = 'The quick brown fox jumps\nover the lazy dog',
		relief = 'sunken', padx = 10, pady = 10)
	self.target.pack(fill = 'both', expand = 1, padx = 10, pady = 10)

	# Create the text to display to the user to represent each font.
	if Demo.fontText == []:
	    for args, dict in Demo.fontList:
		text = args[0]
		if args[1] != 0:
		    text = text + ' ' + str(args[1])
		for name, value in dict.items():
		    text = text + ' ' + name + ': ' + str(value)
		Demo.fontText.append(text)

	# Create a listbox to contain the font selections.
	self.box = Pmw.ScrolledListBox(parent, listbox_selectmode='single', 
		listbox_width = 35,
		listbox_height = 10,
		items=Demo.fontText,
		label_text='Font', labelpos='nw', 
		selectioncommand=self.selectionCommand)
	self.box.pack(fill = 'both', expand = 'yes', padx = 10, pady = 10)

    def selectionCommand(self):
	sel = self.box.curselection()
	if len(sel) > 0:
	    args, dict = Demo.fontList[string.atoi(sel[0])]
	    font = apply(Pmw.logicalfont, args, dict)
	    if Pmw.fontexists(self.parent, font):
		self.target.configure(font = font)
		print font, "  max width:", Pmw.maxfontwidth(self.parent, font)
	    else:
		print 'font does not exist:', font

######################################################################

# Create demo in root window for testing.
if __name__ == '__main__':
    root = Tkinter.Tk()
    Pmw.initialise(root, fontScheme = 'pmw1')
    root.title('Pmw LogicalFont demonstration')

    exitButton = Tkinter.Button(root, text = 'Exit', command = root.destroy)
    exitButton.pack(side = 'bottom')
    widget = Demo(root)
    root.mainloop()

==> python-pmw_0.8.5.orig.tar.gz: Pmw/Pmw_0_8_5/demos/LogicalFont.py <==
title = 'Pmw LogicalFont demonstration'

# Import Pmw from this directory tree.
import sys
sys.path[:0] = ['../../..']

import string
import Tkinter
import Pmw

class Demo:

    # The fonts to demonstrate.
    fontList = (
      (('Times', 0), {}),
      (('Helvetica', 0), {}),
      (('Typewriter', 0), {}),
      (('Fixed', 0), {}),
      (('Helvetica', 2), {'slant' : 'italic'}),
      (('Helvetica', 0), {'size' : 18}),
      (('Helvetica', 0), {'weight' : 'bold'}),
      (('Helvetica', 12), {'weight' : 'bold', 'slant' : 'italic'}),
      (('Typewriter', 0), {'size' : 8, 'weight' : 'bold'}),
      (('Fixed', 0), {'size' : 8, 'weight' : 'bold'}),
      (('Times', 0), {'size' : 24, 'weight' : 'bold', 'slant' : 'italic'}),
      (('Typewriter', 0), {'width' : 'condensed'}),
      (('Typewriter', -1), {'width' : 'condensed'}),
      (('Fixed', 0), {'width' : 'condensed'}),
      (('Fixed', -1), {'width' : 'condensed'}),
      (('Helvetica', 0), {'weight' : 'bogus'}),
    )

    fontText = []

    def __init__(self, parent):

	self.parent = parent

	# Create a label to display the selected font.
	self.target = Tkinter.Label(parent,
	        text = 'The quick brown fox jumps\nover the lazy dog',
		relief = 'sunken', padx = 10, pady = 10)
	self.target.pack(fill = 'both', expand = 1, padx = 10, pady = 10)

	# Create the text to display to the user to represent each font.
	if Demo.fontText == []:
	    for args, dict in Demo.fontList:
		text = args[0]
		if args[1] != 0:
		    text = text + ' ' + str(args[1])
		for name, value in dict.items():
		    text = text + ' ' + name + ': ' + str(value)
		Demo.fontText.append(text)

	# Create a listbox to contain the font selections.
	self.box = Pmw.ScrolledListBox(parent, listbox_selectmode='single', 
		listbox_width = 35,
		listbox_height = 10,
		items=Demo.fontText,
		label_text='Font', labelpos='nw', 
		selectioncommand=self.selectionCommand)
	self.box.pack(fill = 'both', expand = 'yes', padx = 10, pady = 10)

    def selectionCommand(self):
	sel = self.box.curselection()
	if len(sel) > 0:
	    args, dict = Demo.fontList[string.atoi(sel[0])]
	    font = apply(Pmw.logicalfont, args, dict)
            self.target.configure(font = font)
            print font

######################################################################

# Create demo in root window for testing.
if __name__ == '__main__':
    root = Tkinter.Tk()
    Pmw.initialise(root, fontScheme = 'pmw1')
    root.title(title)

    exitButton = Tkinter.Button(root, text = 'Exit', command = root.destroy)
    exitButton.pack(side = 'bottom')
    widget = Demo(root)
    root.mainloop()
